@@ -154,7 +154,7 @@ class KrakenCore:
         return result
 
     def get_user_list(self):
-        _url = +self._token_domain + '/api/auth/v1/user_manager/'
+        _url = self._token_domain + '/api/auth/v1/user_manager/'
         headers = {'Authorization': 'Basic ' + self.token}
         res_json = http_request(_url, method='get', headers=headers)
         if res_json['code'] == 20000:
